@@ -1,24 +1,46 @@
 import json
 import os
 import sys
-from typing import Optional
-
 import typer
 from termcolor import cprint
+from typing import Optional
 
 from jqlite.core import json_ops
 from jqlite.core.filters import Identity, Value
 from jqlite.core.parser import parse
+from . import __version__
 
 
 def main():
     typer.run(run)
 
 
-def run(expr: Optional[str] = typer.Argument(None)):
+def version_callback(value: bool):
+    if value:
+        typer.echo(f"jqlite version {__version__}")
+        raise typer.Exit()
+
+
+def run(
+    expr: Optional[str] = typer.Argument(None),
+    null_stdin: bool = typer.Option(
+        False, "--null-stdin", "-n", help="Do not read from stdin, using null as input."
+    ),
+    version: Optional[bool] = typer.Option(
+        None,
+        "--version",
+        "-v",
+        callback=version_callback,
+        is_eager=True,
+        help="Output jqlite version and exit.",
+    ),
+):
     f = parse(expr) if expr else Identity()
-    json_str = sys.stdin.read()
-    json_obj = json.loads(json_str)
+    if null_stdin:
+        json_obj = None
+    else:
+        json_str = sys.stdin.read()
+        json_obj = json.loads(json_str)
     for v in f.input(json_obj):
         if os.isatty(sys.stdout.fileno()):
             json_print(v)
